#
# spec file for package python-pysolr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pysolr
Version:        3.10.0
Release:        1.5
Summary:        Lightweight python wrapper for Apache Solr
License:        BSD-3-Clause
URL:            https://github.com/django-haystack/pysolr/
Source:         https://files.pythonhosted.org/packages/source/p/pysolr/pysolr-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.9.1
Suggests:       python-kazoo >= 2.5.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.9.1}
# /SECTION
%python_subpackages

%description
Lightweight python wrapper for Apache Solr.

%prep
%setup -q -n pysolr-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# TODO, requires solr server to run

%files %{python_files}
%doc AUTHORS CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/__pycache__
%{python_sitelib}/pysolr.py
%{python_sitelib}/pysolr-%{version}.dist-info

%changelog
* Thu Nov 14 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.10.0
  * Fixed: Different JSON and XML behaviour
  * Fix typo
  * Fix SolrCoreAdmin._get_url content-type
  * enable custom requests session
  * add min_rf feature in add method
  * New: Add parameter for a custom encoder
  * Add accepts empty values
  * Show an example of how to use cursor traversal
  * Escape xml in delete() using ElementTree
  * Update README.rst
  * Update README.rst
  * Perform adds with field updates using JSON
  * Use six.assertRegex instead of assertRegexpMatches
    for Python 3.11 compatibility.
  * GitHub Action to run tox
  * Bump certifi from 2021.10.8 to 2022.12.7
  * Make _to_python recursive for lists and tuples
  * Replace flake8 and isort with ruff
  * Replace ''.join after char filtering with regex filter
  * GitHub Actions: Add Pypy v3.10 and remove EOL CPython 3.7
  * Upgrade github/codeql-action
  * Configure GitHub actions to publish packages
  * fix commitWithin for JSON updates w/o boost
  * Declare a runtime dependency on setuptools
  * Enhance gitignore
  * Set wt=json in _select only if the user has not set it
  * Avoid running tests under PyPy on GitHub Actions
  * GitHub Actions: Add Python 3.12 to the testing
  * Keep GitHub Actions up to date with Dependabot
  * Fix DeprecationWarning from pkg_resources
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Limit Python files matched in %%files section
* Sun Jun 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Wed Apr  6 2022 pgajdos@suse.com
- python-mock is not required for build
* Wed Aug  5 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.9.0
  * Improved SolrCloud support
  * Support for Solr.ping
  * Dropped support for Python 3.4
  * Added JSON interface which can be significantly faster
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Tue Oct  1 2019 pgajdos@suse.com
- initial version 3.8.1, needed by python-django-haystack [SLE-7686]
